@@ -104,7 +104,7 @@ class LearningModule:
                     solution_btn_available=True)
             self.scored_points += task_points
             self.task_points_dict['Aufgabe ' + str(task.task_id)] = \
-                str(task_points) + ' Punkte'
+                str(int(task_points*100)) + ' %'
 
     ####################
     ### Submit score ###
